@@ -481,45 +481,90 @@ serve <- function(emuDBhandle,
             }
             cat("\n")
           }
+          
+          
           ssffFiles = list()
-          # Hash (here: named character vector) with SSFF files extension as key and file path as value
-          # avoids duplicates in ssff files list
-          ssffFilesHash = character(0)
-          for(ssffTr in DBconfig$ssffTrackDefinitions){
-            if(ssffTr[['name']] %in% ssffTrackNmsInUse){
-              fe = ssffTr[['fileExtension']]
-              ssffFilesHash[fe] = normalizePath(file.path(emuDBhandle$basePath, 
-                                                          paste0(bundleSess, session.suffix), 
-                                                          paste0(bundleName, bundle.dir.suffix), 
-                                                          paste0(bundleName, ".", fe)))
+          
+          # List all track definitions actually in use in EMU-webApp
+          tracksInUseDefs = list()
+          for (ssffTr in DBconfig$ssffTrackDefinitions) {
+            if (ssffTr[["name"]] %in% ssffTrackNmsInUse) {
+              tracksInUseDefs[[length(tracksInUseDefs) + 1L]] = ssffTr
             }
           }
-          # read SSFF track file data
-          ssffFileExts = names(ssffFilesHash)
-          for(ssffFileExt in ssffFileExts){
-            ssffFilePath = ssffFilesHash[ssffFileExt]
-            mf = tryCatch(file(ssffFilePath, "rb"), 
-                          error = function(e) {err<<-e})
-            if(is.null(err)){
-              mfData = readBin(mf, 
-                               raw(), 
-                               n = file.info(ssffFilePath)$size)
-              if(inherits(mfData,'error')){
+          
+          for (tr in tracksInUseDefs) {
+            fileExtension  = tr[["fileExtension"]]
+            fileFormat = tr[["fileFormat"]]
+            if (is.null(fileFormat))
+              fileFormat = "ssff"   # Default
+            
+            trackName         = tr[["name"]]
+            columnExpression  = tr[["columnName"]]  # e.g. "data$audio"
+            
+            trackFilePath = normalizePath(file.path(
+              emuDBhandle$basePath,
+              paste0(bundleSess, session.suffix),
+              paste0(bundleName, bundle.dir.suffix),
+              paste0(bundleName, ".", fileExtension)
+            ),
+            mustWork = FALSE)
+            
+            if (!file.exists(trackFilePath)) {
+              err = simpleError(paste0(
+                "Track file not found for track '",
+                trackName,
+                "': ",
+                trackFilePath
+              ))
+              break
+            }
+            
+            if (identical(fileFormat, "Rda")) {
+              # ---------- Rda → SSFF on-the-fly conversion ----------
+              mfData = tryCatch(
+                rdaTrackToSsff(
+                  rdaPath          = trackFilePath,
+                  columnExpression = columnExpression
+                ),
+                error = function(e) {
+                  err <<- e
+                  NULL
+                }
+              )
+              if (!is.null(err))
+                break
+              
+            } else {
+              # ---------- SSFF file, no conversion ----------
+              mf = tryCatch(
+                file(trackFilePath, "rb"),
+                error = function(e) {
+                  err <<- e
+                  NULL
+                }
+              )
+              if (!is.null(err))
+                break
+              
+              mfData = readBin(mf, what = "raw", n = file.info(trackFilePath)$size)
+              close(mf)
+              if (inherits(mfData, "error")) {
                 err = mfData
                 break
               }
-            }else{
-              break
             }
+            
             mfDataBase64 = base64enc::base64encode(mfData)
-            encoding = "BASE64"
-            ssffDatObj = list(encoding = encoding, 
-                              data = mfDataBase64,
-                              fileExtension = ssffFileExt)
-            ssffFiles[[length(ssffFiles) + 1]] = ssffDatObj
-            close(mf)
+            ssffDatObj = list(encoding      = "BASE64",
+                              data          = mfDataBase64,
+                              fileExtension = fileExtension)
+            ssffFiles[[length(ssffFiles) + 1L]] = ssffDatObj
+            
           }
-          if(is.null(err)){
+          
+          
+          if (is.null(err)) {
             data = list(mediaFile = mediaFile,
                         ssffFiles = ssffFiles,
                         annotation = b)
@@ -921,3 +966,45 @@ guess_type <- function (path)
   mimetype(stdout = TRUE)
 }
 
+
+#' Converts a signal track from Rda to SSFF
+#' 
+#' The SSFF track briefly hits the disk, but the return value of this function is in-memory only.
+#'
+#' @param rdaPath Path to the Rda file containing the signal track
+#' @param columnExpression The R expression needed to extract the desired signal data from the Rda file, for example `data$audio` or `data$velumgridsigUS`
+#' @return Raw contents of an SSFF-encoded file
+rdaTrackToSsff <- function(rdaPath,
+                           columnExpression) {
+  ## --- 1. Load Rda file ---
+  rdaFileEnvironment = rlang::new_environment()
+  load(rdaPath, envir = rdaFileEnvironment)
+  
+  allDataFromRdaFile <- rdaFileEnvironment$data
+  requestedData <- eval(parse(text = columnExpression)[[1]], envir = list(data = allDataFromRdaFile))
+  requestedData <- as.matrix(requestedData)
+  
+  ## --- 2. Build new AsspDataObj from scratch ---
+  ado <- list()
+  class(ado) <- "AsspDataObj"
+  ado = wrassp::addTrack(dobj = ado,
+                         trackname = columnExpression,
+                         data = requestedData,
+                         format = "REAL64")
+  
+  attr(ado, "sampleRate")   <- rdaFileEnvironment$sampleRate
+  attr(ado, "origFreq")     <- rdaFileEnvironment$originalFrequency
+  attr(ado, "startTime")    <- rdaFileEnvironment$startTime
+  
+  
+  ## --- 3. Write temporary file ---
+  wrassp::AsspFileFormat(ado) = "SSFF"
+  wrassp::AsspDataFormat(ado) = "binary"
+  tmpPath <- tempfile(fileext = ".ssff")
+  on.exit(unlink(tmpPath), add = TRUE)
+  
+  wrassp::write.AsspDataObj(ado, file = tmpPath)
+  
+  ## --- 4. Return raw SSFF file contents ---
+  readBin(tmpPath, "raw", file.info(tmpPath)$size)
+}
